gnucash-htdocs master: Clean up version mismatch from new major release

Frank H.Ellenberger fell at code.gnucash.org
Sat Jul 4 12:46:29 EDT 2020


Updated	 via  https://github.com/Gnucash/gnucash-htdocs/commit/d35d6ed4 (commit)
	from  https://github.com/Gnucash/gnucash-htdocs/commit/2ab573ab (commit)



commit d35d6ed497c1b46dfeff282cf74f2f74bdd95528
Author: Frank H. Ellenberger <frank.h.ellenberger at gmail.com>
Date:   Sat Jul 4 18:46:14 2020 +0200

    Clean up version mismatch from new major release

diff --git a/download.phtml b/download.phtml
index 489cb6b..96dd06c 100644
--- a/download.phtml
+++ b/download.phtml
@@ -54,7 +54,7 @@
 
   <?php
     # Only show unstable download options if there really is an active unstable release
-    if ($latest_unstable) { ?>
+    if ($show_unstable) { ?>
       <div class="featureborder">
       <h2 class="featuretitle"><?php printf (T_("Unstable/Development release (%s)"), $latest_unstable)?></h2>
       </div>
@@ -78,8 +78,8 @@
       <p class="justify"><?php printf (T_("The last old stable release of <span class=\"gnucash\">GnuCash</span> is %s.  Choose the download for your operating system below."), $old_stable)?></p>
       
       <ul>
-        <li><?php printf (T_("GnuCash %s for"), $old_stable)?> <a href="<?php echo $old_stable_path.$old_stable_win;?>">Microsoft Windows XP/Vista/7/8/10</a></li>
-        <li><?php printf (T_("GnuCash %s for"), $old_stable)?> Mac OS X <a href="<?php echo $old_stable_path.$old_stable_mac_intel;?>">Intel</a> | <a href="<?php echo $old_stable_path.$old_stable_mac_ppc;?>">PPC</a></li>
+        <li><?php printf (T_("GnuCash %s for"), $old_stable)?> <a href="<?php echo $old_stable_path.$old_stable_win;?>">Microsoft Windows 7/8/10</a></li>
+        <li><?php printf (T_("GnuCash %s for"), $old_stable)?> Apple macOS <a href="<?php echo $old_stable_path.$old_stable_mac_intel;?>">Intel</a></li>
         <li><a href="<?php echo $old_stable_path.$old_stable_source;?>">bzip2 compressed tarball</a> <?php printf (T_("for GnuCash %s"), $old_stable)?></li>
       </ul>
   <?php } ?>
@@ -92,7 +92,12 @@
       </div>
       <p class="justify"><?php echo T_("This versions are really old. Do not expect any support.")?></p>
       <ul>
-        <li><?php printf (T_("GnuCash %s for"), $latest_stable_win2k_version)?> <a href="<?php echo $latest_stable_path.$latest_stable_win2k;?>">Microsoft Windows 2000</a></li>
+        <li><?php printf (T_("GnuCash %s for"), $last_xp_vista_version)?>
+          <ul>
+            <li><a href="<?php echo $latest_stable_path.$last_xp_vista;?>">Microsoft Windows XP/Vista</a></li>
+            <li><a href="<?php echo $latest_stable_path.$last_mac_ppc;?>">Mac OS X Power PC</a></li>
+        </ul>
+        <li><?php printf (T_("GnuCash %s for"), $last_win2k_version)?> <a href="<?php echo $latest_stable_path.$last_win2k;?>">Microsoft Windows 2000</a></li>
       </ul>
   <?php } ?>
 
diff --git a/index.phtml b/index.phtml
index b503cdf..b886c38 100644
--- a/index.phtml
+++ b/index.phtml
@@ -19,8 +19,8 @@
 
         <ul>
          <li><img alt="linux" src="<?=$top_dir?>/images/icons/linux.png" /> Linux <a href="<?php echo $latest_stable_path.$latest_stable_source;?>"><?php echo T_("Source");?></a> | <a href="<?=$home?>/download.phtml#distribution"><?php echo T_("Via distribution");?></a></li>
-         <li><img alt="windows" src="<?=$top_dir?>/images/icons/windows.png" /> Microsoft Windows <a href="<?php echo $latest_stable_path.$latest_stable_xp_vista;?>">XP/Vista</a> | <a href="<?php echo $latest_stable_path.$latest_stable_win;?>">7/8/10</a></li>
-         <li><img alt="macosx" src="<?=$top_dir?>/images/icons/macosx.png" /> Mac OS X <a href="<?php echo $latest_stable_path.$latest_stable_mac_intel;?>">Intel</a> | <a href="<?php echo $latest_stable_path.$latest_stable_mac_ppc;?>">Power PC</a></li>
+         <li><img alt="windows" src="<?=$top_dir?>/images/icons/windows.png" /> Microsoft Windows <a href="<?php echo $latest_stable_path.$latest_stable_win;?>">8/10</a></li>
+         <li><img alt="macosx" src="<?=$top_dir?>/images/icons/macosx.png" /> Apple macOS <a href="<?php echo $latest_stable_path.$latest_stable_mac_intel;?>">>= 10.13 (High Sierra)</a></li>
          <li><a href="<?=$home?>/download.phtml" style="font-size: 80%;"><?=T_("More downloads (Source, Development,...)")?></a></li>
         </ul>
       </div>
@@ -30,9 +30,9 @@
       </div>
 
       <div style="float:left;">
-          <p><?php printf (T_("Version %s is the last version for Windows 7 and MacOS 10.12 and earlier."), $last_stable_win7_version);?></p>
+        <p><?php printf (T_("Version %s is the last version for Windows 7 and MacOS 10.12 and earlier."), $last_stable_win7_version);?></p>
         <p><?php printf (T_("Version %s is the last version for Windows XP/Vista and MacOS X 10.8 and earlier, and so the last version that will run on PowerPC Macs."),
-                  $latest_stable_xp_vista_version);?></p>
+                  $last_xp_vista_version);?></p>
       </div>
     </div>
 



Summary of changes:
 download.phtml              | 13 +++++++++----
 externals/global_params.php | 33 +++++++++++++++++----------------
 index.phtml                 |  8 ++++----
 3 files changed, 30 insertions(+), 24 deletions(-)



More information about the gnucash-changes mailing list
diff --git a/externals/global_params.php b/externals/global_params.php
index e0daf3f..4f4cd5f 100644
--- a/externals/global_params.php
+++ b/externals/global_params.php
@@ -3,8 +3,8 @@
      // Each platform can define its own latest version or follow the default.
      // Both a latest stable version and a latest unstable version are defined.
      $major_stable              ="4";
      // FIXME: on major_stable 4 copy in download.phtml into the historical
      // section: $latest_stable_xp_vista_version and $latest_stable_mac_ppc
      $minor_stable              ="0";
      $latest_stable             = $major_stable.".".$minor_stable;
      $latest_stable_win         = $latest_stable;
@@ -14,11 +14,11 @@
 // e.g. if one retagged 2.6.13 to 2.6.13a, make $tarball = $latest_stable."a".
      $tarball                   = $latest_stable."";
 
-     $major_latest_unstable             ="3";
-     $minor_latest_unstable             ="906";
-     $latest_unstable           = $major_latest_unstable.".".$minor_latest_unstable;
-// To publicize an unstable release comment out the next line or change the value to True:
-     $latest_unstable           = False;
+     $major_unstable            ="3";
+     $minor_latest_unstable     ="906";
+     $latest_unstable           = $major_unstable.".".$minor_latest_unstable;
+// To publicize an unstable release:
+     $show_unstable             = $major_unstable >= $major_stable;
      $latest_unstable_win       = $latest_unstable;
      $latest_unstable_mac_intel = $latest_unstable."-1";
 
@@ -26,15 +26,15 @@
      $minor_old_stable          ="11";
      $old_stable            = $major_old_stable.".".$minor_old_stable;
      $old_stable_win        = $old_stable;
-     $old_stable_mac_ppc  = $old_stable."-1";
      $old_stable_mac_intel  = $old_stable."-1";
 
      // Frozen versions:
-     $last_stable_win7_version = "3.11"; //Used in download block on index.phtml
-     $latest_stable_xp_vista_version = "2.6.21"; // used also in text
-     $latest_stable_mac_ppc  = "2.6.21-1";
      $show_historical = True;
-     $latest_stable_win2k_version = "2.2.9";
+     $last_win7_version = "3.11"; //Still used in download block on index.phtml
+     $last_mac_sierra  = "3.11-1";
+     $last_xp_vista_version = "2.6.21"; // used also in text
+     $last_mac_ppc  = "2.6.21-1";
+     $last_win2k_version = "2.2.9";
 
      // The definitions below use the latest version definitions above
      // to define several paths that will be used on several pages
@@ -45,17 +45,18 @@
      $latest_stable_path=$stable_path.$latest_stable."/";
 
      $latest_stable_win="gnucash-".$latest_stable_win.".setup.exe";
-     $latest_stable_xp_vista="gnucash-".$latest_stable_xp_vista_version."-setup.exe";
-     $latest_stable_win2k="gnucash-".$latest_stable_win2k_version.".setup.exe";
+     $last_win7="gnucash-".$last_win7.".setup.exe";
+     $last_xp_vista="gnucash-".$last_xp_vista_version."-setup.exe";
+     $last_win2k="gnucash-".$last_win2k_version.".setup.exe";
      $latest_stable_mac_intel="Gnucash-Intel-".$latest_stable_mac_intel.".dmg";
-     $latest_stable_mac_ppc="Gnucash-PPC-".$latest_stable_mac_ppc.".dmg";
+     $last_mac_sierra="Gnucash-Intel-".$last_mac_sierra.".dmg";
+     $last_mac_ppc="Gnucash-PPC-".$last_mac_ppc.".dmg";
      $latest_stable_source="gnucash-".$tarball.".tar.bz2";
 
      $old_stable_path=$stable_path.$old_stable."/";
 
      $old_stable_win="gnucash-".$old_stable_win."-setup.exe";
      $old_stable_mac_intel="Gnucash-Intel-".$old_stable_mac_intel.".dmg";
-     $old_stable_mac_ppc="Gnucash-PPC-".$old_stable_mac_ppc.".dmg";
      $old_stable_source="gnucash-".$old_stable.".tar.bz2";
 
      $unstable_path=$base_path . "/gnucash%20(unstable)/";
@@ -3,8 +3,8 @@
      // Both a latest stable version and a latest unstable version are defined.
      $major_stable              ="4";
-     // FIXME: on major_stable 4 copy in download.phtml into the historical
-     // section: $latest_stable_xp_vista_version and $latest_stable_mac_ppc
+     // TODO: on major_stable 5 in download.phtml copy from $old_stable into the historical
+     // section: last_win7 and $last_mac_sierra
      $minor_stable              ="0";
      $latest_stable             = $major_stable.".".$minor_stable;